@@ -2,7 +2,7 @@
  *
  * s t k . c
  *
- * Copyright (C) 1993, 1994 Erick Gallesio - I3S - CNRS / UNSA <eg@unice.fr>
+ * Copyright (C) 1993,1994,1995 Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
  * 
  *
  * Permission to use, copy, and/or distribute this software and its
@@ -19,15 +19,15 @@
  *
  *           Author: Erick Gallesio [eg@unice.fr]
  *    Creation date: 12-May-1993 10:34
- * Last file update:  5-Apr-1994 13:51
+ * Last file update:  1-Feb-1995 22:43
  *
  ******************************************************************************/
-
+#define STK_MAIN
 #include "stk.h"
 
 int main(int argc,char **argv)
 {
-  toplevel(argc, argv);
+  STk_toplevel(argc, argv);
   exit(0);
 }
 
