@@ -2,7 +2,7 @@
  *
  * t k - g l u e . h 		- Glue function between the scheme and Tk worlds
  *
- * Copyright (C) 1993, 1994 Erick Gallesio - I3S - CNRS / UNSA <eg@unice.fr>
+ * Copyright (C) 1993,1994,1995 Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
  * 
  *
  * Permission to use, copy, and/or distribute this software and its
@@ -19,18 +19,10 @@
  *
  *            Author: Erick Gallesio [eg@unice.fr]
  *    Creation date: 19-Feb-1993 22:15
- * Last file update: 21-Dec-1993 22:40
+ * Last file update:  2-Feb-1995 23:04
  *
  *
  */
 
 /* Scheme objects used to represent the "." pseudo widget and its name */
-extern
-SCM root_window, root_window_name;
-
-void Keep_result_as_string(char *s);
-
-
-void init_glue(void);
-char *convert_for_tk(SCM obj);
-SCM execute_Tk_lib_cmd(SCM cmd, SCM args, SCM env, int eval_args);
+extern SCM STk_root_window, STk_root_window_name;
