@@ -618,7 +618,6 @@ Tk_CreateMainWindow(interp, screenName, baseName, className)
     register TkMainInfo *mainPtr;
     register TkWindow *winPtr;
     register TkCmd *cmdPtr;
-    char *libDir;
     static char *argv[] = {"-width", "200", "-height", "200", (char *) NULL};
 
     /*
@@ -694,16 +693,14 @@ Tk_CreateMainWindow(interp, screenName, baseName, className)
     /*
      * Set variables for the intepreter.
      */
+    {
+      extern char *STk_library_path;
 
-    libDir = getenv("STK_LIBRARY");
-    if (libDir == NULL) {
-	libDir = STK_LIBRARY;
+      Tcl_SetVar(interp, "tk_library", STk_library_path, TCL_GLOBAL_ONLY);
+      Tcl_SetVar(interp, "tk_patchLevel", TK_PATCH_LEVEL, TCL_GLOBAL_ONLY);
+      Tcl_SetVar(interp, "tk_version", TK_VERSION, TCL_GLOBAL_ONLY);
+      Tcl_SetVar(interp, "tkVersion", TK_VERSION, TCL_GLOBAL_ONLY);
     }
-    Tcl_SetVar(interp, "tk_library", libDir, TCL_GLOBAL_ONLY);
-    Tcl_SetVar(interp, "tk_patchLevel", TK_PATCH_LEVEL, TCL_GLOBAL_ONLY);
-    Tcl_SetVar(interp, "tk_version", TK_VERSION, TCL_GLOBAL_ONLY);
-    Tcl_SetVar(interp, "tkVersion", TK_VERSION, TCL_GLOBAL_ONLY);
-
     /*
      * Make the main window into a toplevel widget.
      */
